/* Reflow Oven Controller
*
* Copyright (C) 2022  Mario Hüttel <mario.huettel@gmx.net>
*
* This file is part of the Reflow Oven Controller Project.
*
* The reflow oven controller is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License version 2 as
* published by the Free Software Foundation.
*
* The Reflow Oven Control Firmware is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with the reflow oven controller project.
* If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _SAFETY_FLASH_CRC_H_
#define _SAFETY_FLASH_CRC_H_

#include <stdint.h>

enum flash_crc_section {
    FLASH_CRC_VECTOR = 0,
    FLASH_CRC_TEXT,
    FLASH_CRC_DATA,
    FLASH_CRC_CCMDATA,
    N_FLASH_CRC,
};

/**
 * @brief Perform a CRC check of the flash memory and set appropriate flags
 * @return negative if internal error occured. Otherwise (independent from CRC check result) 0.
 * @note This function requires the safety controller (and CRC unit) to be set up before calling!
 */
int flash_crc_trigger_check(void);

/**
 * @brief Calculate CRC over flash section
 * @param sec Section to calculate CRC over
 * @param[out] crc_result Calculated CRC
 * @return negative if internal error occured. Otherwise (independent from CRC check result) 0.
 */
int flash_crc_calc_section(enum flash_crc_section sec, uint32_t *crc_result);

/**
 * @brief Get expected CRC value of a section
 * @param sec Section
 * @return Expected CRC
 */
uint32_t flash_crc_get_expected_crc(enum flash_crc_section sec);

#endif /* _SAFETY_FLASH_CRC_H_ */
