/* Reflow Oven Controller
 *
 * Copyright (C) 2022  Mario Hüttel <mario.huettel@gmx.net>
 *
 * This file is part of the Reflow Oven Controller Project.
 *
 * The reflow oven controller is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * GDSII-Converter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the reflow oven controller project.
 * If not, see <http://www.gnu.org/licenses/>.
 */

 #ifndef _SD_H_
 #define _SD_H_

#include <stdbool.h>
#include <fatfs/ff.h>

/**
 * @brief Mount the SD card if available and not already mounted
 * @param fs Filesystem to mount to.
 * @return true if mounted, false if an error occured or the SD is not inserted and cannot be mounted
 */
bool mount_sd_card_if_avail(FATFS *fs);

/**
 * @brief Return whether an SD card is inserted and mounted
 * 
 * @return true SD inserted and mounted
 * @return false No SD inserted or not mounted
 */
bool sd_card_is_mounted(void);

#endif /* _SD_H_ */